@@ -23,14 +23,12 @@ class.  For those wishing to override the braille generators, however,
 one can create a new instance and replace/extend the braille
 generators as they see fit."""
 
-__id__        = "$Id: braillegenerator.py 3165 2007-10-23 21:22:59Z joanied $"
-__version__   = "$Revision: 3165 $"
-__date__      = "$Date: 2007-10-23 17:22:59 -0400 (Tue, 23 Oct 2007) $"
+__id__        = "$Id: braillegenerator.py 3222 2007-11-06 20:38:59Z richb $"
+__version__   = "$Revision: 3222 $"
+__date__      = "$Date: 2007-11-06 15:38:59 -0500 (Tue, 06 Nov 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
-import math
-
 import pyatspi
 import braille
 import debug
@@ -204,58 +202,6 @@ class BrailleGenerator:
         else:
             return None
 
-    def _getTextForValue(self, obj):
-        """Returns the text to be displayed for the object's current value.
-
-        Arguments:
-        - obj: the Accessible object that may or may not have a value.
-
-        Returns a string representing the value.
-        """
-
-        try:
-            value = obj.queryValue()
-        except NotImplementedError:
-            return ""
-
-        # OK, this craziness is all about trying to figure out the most
-        # meaningful formatting string for the floating point values.
-        # The number of places to the right of the decimal point should
-        # be set by the minimumIncrement, but the minimumIncrement isn't
-        # always set.  So...we'll default the minimumIncrement to 1/100
-        # of the range.  But, if max == min, then we'll just go for showing
-        # them off to two meaningful digits.
-        #
-        try:
-            minimumIncrement = value.minimumIncrement
-        except:
-            minimumIncrement = 0.0
-
-        if minimumIncrement == 0.0:
-            minimumIncrement = (value.maximumValue - value.minimumValue) \
-                               / 100.0
-
-        try:
-            decimalPlaces = max(0, -math.log10(minimumIncrement))
-        except:
-            try:
-                decimalPlaces = max(0, -math.log10(value.minimumValue))
-            except:
-                try:
-                    decimalPlaces = max(0, -math.log10(value.maximumValue))
-                except:
-                    decimalPlaces = 0
-
-        formatter = "%%.%df" % decimalPlaces
-        valueString = formatter % value.currentValue
-        #minString   = formatter % value.minimumValue
-        #maxString   = formatter % value.maximumValue
-
-        # [[[TODO: WDW - probably want to do this as a percentage at some
-        # point?  Logged as bugzilla bug 319743.]]]
-        #
-        return valueString
-
     def _getTextForRole(self, obj, role=None):
         if (settings.brailleVerbosityLevel \
             == settings.VERBOSITY_LEVEL_VERBOSE)\
@@ -304,7 +250,8 @@ class BrailleGenerator:
             text, self._script.getDisplayedLabel(obj))
         text = self._script.appendString(
             text, self._script.getDisplayedText(obj))
-        text = self._script.appendString(text, self._getTextForValue(obj))
+        text = self._script.appendString(text, 
+                                         self._script.getTextForValue(obj))
         text = self._script.appendString(text, self._getTextForRole(obj, role))
 
         regions = []
@@ -869,6 +816,7 @@ class BrailleGenerator:
             text, self._script.getDisplayedLabel(obj))
         text = self._script.appendString(
             text, self._script.getDisplayedText(obj))
+        text = self._script.appendString(text, self._getTextForRole(obj))
 
         if obj == orca_state.locusOfFocus:
             text = self._script.appendString(
@@ -1113,7 +1061,8 @@ class BrailleGenerator:
         # Ignore the text on the slider.
         #text = self._script.appendString(
         #    text, self._script.getDisplayedText(obj))
-        text = self._script.appendString(text, self._getTextForValue(obj))
+        text = self._script.appendString(text,
+                                         self._script.getTextForValue(obj))
         text = self._script.appendString(text, self._getTextForRole(obj))
 
         regions = []
