@@ -20,9 +20,9 @@
 """Provides a graphical braille display at the top of the screen.
 This is mainly for debugging and for demonstrations."""
 
-__id__        = "$Id: brlmon.py 2520 2007-07-06 19:51:57Z joanied $"
-__version__   = "$Revision: 2520 $"
-__date__      = "$Date: 2007-07-06 15:51:57 -0400 (Fri, 06 Jul 2007) $"
+__id__        = "$Id: brlmon.py 3076 2007-10-17 15:43:22Z richb $"
+__version__   = "$Revision: 3076 $"
+__date__      = "$Date: 2007-10-17 11:43:22 -0400 (Wed, 17 Oct 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -78,7 +78,8 @@ class BrlMon(gtk.Window):
         self.add(hbox)
         self.cellFrames = []
         self.cellLabels = []
-        for i in range(0, numCells):
+        i = 0
+        while (i < numCells):
             frame = gtk.Frame()
             frame.set_shadow_type(gtk.SHADOW_OUT)
             label = gtk.Label(" ")
@@ -87,6 +88,7 @@ class BrlMon(gtk.Window):
             hbox.add(frame)
             self.cellFrames.append(frame)
             self.cellLabels.append(label)
+            i += 1
 
         # This prevents it from getting focus.
         #
@@ -150,6 +152,8 @@ class BrlMon(gtk.Window):
                 char = "&lt;"
             elif string[i] == "&":
                 char = "&amp;"
+            elif string[i] == "\t":
+                char = "$t"
             else:
                 char = string[i]
 
