@@ -19,13 +19,13 @@
 
 """Provides support for synthesizing keyboard and mouse events."""
 
-__id__        = "$Id: eventsynthesizer.py,v 1.8 2006/10/06 07:59:03 richb Exp $"
-__version__   = "$Revision: 1.8 $"
-__date__      = "$Date: 2006/10/06 07:59:03 $"
+__id__        = "$Id: eventsynthesizer.py 3153 2007-10-22 19:18:04Z eitani $"
+__version__   = "$Revision: 3153 $"
+__date__      = "$Date: 2007-10-22 15:18:04 -0400 (Mon, 22 Oct 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
-import atspi
+import pyatspi
 import debug
 
 def generateMouseEvent(x, y, eventName):
@@ -47,8 +47,7 @@ def generateMouseEvent(x, y, eventName):
                   "SYNTHESIZING MOUSE EVENT: (%d, %d) %s"\
                   % (x, y, eventName))
 
-    d = atspi.Registry().registry.getDeviceEventController()
-    d.generateMouseEvent(x, y, eventName)
+    pyatspi.Registry.generateMouseEvent(x, y, eventName)
 
 def clickObject(obj, button):
     """Performs a button click on the given Accessible.
@@ -57,8 +56,7 @@ def clickObject(obj, button):
     - obj: the Accessible
     - button: an integer representing the mouse button number
     """
-
-    extents = obj.extents
+    extents = obj.queryComponent().getExtents(pyatspi.DESKTOP_COORDS)
     x = extents.x + extents.width/2
     y = extents.y + extents.height/2
     generateMouseEvent(x, y, "b%dc" % button)
@@ -87,9 +85,8 @@ def generateKeyboardEvent(keycode, keystring, type):
               as though a composing input method (such as XIM) were used.
     - type:   an AccessibleKeySynthType flag indicating whether keyval
               is to be interpreted as a keysym rather than a keycode
-              (atspi.Accessibility.KEY_SYM), or whether to synthesize
+              (pyatspi.KEY_SYM), or whether to synthesize
               KEY_PRESS, KEY_RELEASE, or both (KEY_PRESSRELEASE).
     """
 
-    d = atspi.Registry().registry.getDeviceEventController()
-    d.generateKeyboardEvent(keycode, keystring, type)
+    pyatspi.Registry.generateKeyboardEvent(keycode, keystring, type)
