@@ -20,9 +20,9 @@
 """Uses speech prompts and a command line interface to set Orca
 user preferences."""
 
-__id__        = "$Id: orca_console_prefs.py 2772 2007-09-04 17:26:32Z wwalker $"
-__version__   = "$Revision: 2772 $"
-__date__      = "$Date: 2007-09-04 13:26:32 -0400 (Tue, 04 Sep 2007) $"
+__id__        = "$Id: orca_console_prefs.py 3081 2007-10-17 18:12:10Z richb $"
+__version__   = "$Revision: 3081 $"
+__date__      = "$Date: 2007-10-17 14:12:10 -0400 (Wed, 17 Oct 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -69,14 +69,14 @@ speechVoiceChoice  = None
 YESEXPR = re.compile(_("^[Yy1]"))
 
 def checkYes(value) :
-     """Checks if a string represents a yes.
+    """Checks if a string represents a yes.
 
-     Arguments:
-     - value: a string read from the console
+    Arguments:
+    - value: a string read from the console
 
-     Returns True if the argument represents a yes
-     """
-     return YESEXPR.match(value) != None
+    Returns True if the argument represents a yes
+    """
+    return YESEXPR.match(value) != None
 
 def sayAndPrint(text,
                 stop=False,
@@ -314,7 +314,8 @@ def setupSpeech(prefsDict):
         # Translators: this is in reference to key echo for
         # normal text entry keys.
         #
-        answer = sayAndPrint(_("Enable alphanumeric and punctuation keys?  Enter y or n: "),
+        answer = sayAndPrint( \
+          _("Enable alphanumeric and punctuation keys?  Enter y or n: "),
                              True,
                              True,
                              speechServerChoice,
@@ -415,7 +416,6 @@ def logoutUser():
     """Automatically log the user out of the GNOME desktop."""
 
     import gnome
-    import gnome.ui
 
     gnome.init(platform.package, platform.version)
     client = gnome.ui.master_client()
@@ -465,14 +465,16 @@ def showPreferencesUI():
                     False,
                     speechServerChoice,
                     speechVoiceChoice)
-        sayAndPrint(_("You need to log out and log back in for the change to take effect."),
+        sayAndPrint( \
+        _("You need to log out and log back in for the change to take effect."),
                     False,
                     False,
                     speechServerChoice,
                     speechVoiceChoice)
 
         if desktopRunning:
-            answer = sayAndPrint(_("Do you want to logout now?  Enter y or n: "),
+            answer = sayAndPrint( \
+                _("Do you want to logout now?  Enter y or n: "),
                                  False,
                                  True,
                                  speechServerChoice,
