@@ -19,27 +19,21 @@
 
 """Displays a GUI for the Orca main window."""
 
-__id__        = "$Id: orca_gui_main.py 3032 2007-10-12 19:31:00Z richb $"
-__version__   = "$Revision: 3032 $"
-__date__      = "$Date: 2007-10-12 15:31:00 -0400 (Fri, 12 Oct 2007) $"
+__id__        = "$Id: orca_gui_main.py 3077 2007-10-17 16:32:55Z richb $"
+__version__   = "$Revision: 3077 $"
+__date__      = "$Date: 2007-10-17 12:32:55 -0400 (Wed, 17 Oct 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import os
 import sys
-import debug
-import gettext
 import gtk
-import gtk.glade
 import locale
 
 import orca
 import orca_glade
-import orca_state
 import platform
 
-from orca_i18n import _  # for gettext support
-
 OS = None
 
 class orcaMainGUI(orca_glade.GladeWrapper):
@@ -56,7 +50,7 @@ class orcaMainGUI(orca_glade.GladeWrapper):
         except:
             return
 
-        self.mainWindow.set_icon(icon)
+        self.get_widget("mainWindow").set_icon(icon)
 
     def _showGUI(self):
         """Show the Orca main window GUI. This assumes that the GUI has 
@@ -64,14 +58,14 @@ class orcaMainGUI(orca_glade.GladeWrapper):
         """
 
         self._setMainWindowIcon()
-        self.mainWindow.show()
+        self.get_widget("mainWindow").show()
 
     def _hideGUI(self):
         """Hide the Orca main window GUI. This assumes that the GUI has
         already been created.
         """
 
-        self.mainWindow.hide()
+        self.get_widget("mainWindow").hide()
 
     def helpButtonClicked(self, widget):
         """Signal handler for the "clicked" signal for the helpButton
