@@ -27,22 +27,21 @@ The following script specific key sequences are supported:
   Insert-[1-9]  -  Speak and braille a previous chat room message.
 """
 
-__id__        = "$Id: gaim.py 2821 2007-09-12 14:28:07Z wwalker $"
-__version__   = "$Revision: 2821 $"
-__date__      = "$Date: 2007-09-12 10:28:07 -0400 (Wed, 12 Sep 2007) $"
+__id__        = "$Id: gaim.py 3108 2007-10-19 02:17:54Z joanied $"
+__version__   = "$Revision: 3108 $"
+__date__      = "$Date: 2007-10-18 22:17:54 -0400 (Thu, 18 Oct 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import gtk
+import pyatspi
 
-import orca.atspi as atspi
 import orca.braille as braille
 import orca.debug as debug
 import orca.default as default
 import orca.input_event as input_event
 import orca.keybindings as keybindings
 import orca.orca_state as orca_state
-import orca.rolenames as rolenames
 import orca.settings as settings
 import orca.speech as speech
 
@@ -123,10 +122,15 @@ class Script(default.Script):
 
         # Initially populate the cyclic lists with empty strings.
         #
-        for i in range(0, self.previousMessages.maxsize()):
+        i = 0
+        while i < self.previousMessages.maxsize():
             self.previousMessages.append("")
-        for i in range(0, self.previousChatRoomNames.maxsize()):
+            i += 1
+
+        i = 0
+        while i < self.previousChatRoomNames.maxsize():
             self.previousChatRoomNames.append("")
+            i += 1
 
         # Keep track of the various text areas for chatting.
         # The key is the tab and the value is the text area where
@@ -137,7 +141,7 @@ class Script(default.Script):
         default.Script.__init__(self, app)
 
     def getListeners(self):
-        """Add in an AT-SPI event listener ""object:children-changed:"
+        """Add in an AT-SPI event listener "object:children-changed:"
         events, for this script.
         """
 
@@ -340,9 +344,9 @@ class Script(default.Script):
         if obj:
             while True:
                 if obj:
-                    if obj.role == rolenames.ROLE_APPLICATION:
+                    if obj.getRole() == pyatspi.ROLE_APPLICATION:
                         break
-                    elif obj.role == rolenames.ROLE_PAGE_TAB:
+                    elif obj.getRole() == pyatspi.ROLE_PAGE_TAB:
                         return obj
                     else:
                         obj = obj.parent
@@ -362,12 +366,10 @@ class Script(default.Script):
         # has, then announce its name. See bug #469098 for more details.
         #
         if event.type.startswith("object:children-changed:add"):
-            rolesList = [rolenames.ROLE_PAGE_TAB_LIST, \
-                         rolenames.ROLE_FILLER, \
-                         rolenames.ROLE_FRAME]
+            rolesList = [pyatspi.ROLE_PAGE_TAB_LIST, \
+                         pyatspi.ROLE_FILLER, \
+                         pyatspi.ROLE_FRAME]
             if self.isDesiredFocusedItem(event.source, rolesList):
-                childCount = event.source.childCount
-
                 # As it's possible to get this component hierarchy in other
                 # places than the chat room (i.e. the Preferences dialog),
                 # we check to see if the name of the frame is the same as one
@@ -377,12 +379,11 @@ class Script(default.Script):
                 #
                 nameFound = False
                 frameName = event.source.parent.parent.name
-                for i in range(0, childCount):
-                    child = event.source.child(i)
+                for child in event.source:
                     if frameName and (frameName == child.name):
                         nameFound = True
                 if nameFound:
-                    child = event.source.child(childCount-1)
+                    child = event.source[-1]
                     if child.name:
                         line = _("New chat tab %s") % child.name
                         speech.speak(line)
@@ -426,7 +427,7 @@ class Script(default.Script):
             # as well, but is currently untested.
             #
             allTextFields = self.findByRole(chatRoomTab,
-                                            rolenames.ROLE_TEXT,
+                                            pyatspi.ROLE_TEXT,
                                             False)
             index = len(allTextFields) - 2
             if index >= 0:
@@ -453,7 +454,8 @@ class Script(default.Script):
             # If the new message came from the room with focus, we don't
             # want to speak its name even if prefixChatMessage is enabled.
             #
-            if event.source.state.count(atspi.Accessibility.STATE_SHOWING):
+            state = event.source.getState()
+            if state.contains(pyatspi.STATE_SHOWING):
                 chatRoomName = ""
             self.utterMessage(chatRoomName, message)
 
