@@ -19,19 +19,18 @@
 
 """Custom script for gedit."""
 
-__id__        = "$Id: gedit.py 2821 2007-09-12 14:28:07Z wwalker $"
-__version__   = "$Revision: 2821 $"
-__date__      = "$Date: 2007-09-12 10:28:07 -0400 (Wed, 12 Sep 2007) $"
+__id__        = "$Id: gedit.py 3230 2007-11-09 17:02:46Z richb $"
+__version__   = "$Revision: 3230 $"
+__date__      = "$Date: 2007-11-09 12:02:46 -0500 (Fri, 09 Nov 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
+import pyatspi
+
 import orca.debug as debug
-import orca.atspi as atspi
-import orca.braille as braille
 import orca.default as default
 import orca.orca as orca
 import orca.orca_state as orca_state
-import orca.rolenames as rolenames
 import orca.settings as settings
 import orca.speech as speech
 import orca.speechgenerator as speechgenerator
@@ -123,16 +122,17 @@ class Script(default.Script):
             offset = context.currentOffset
             for i in range(0, len(context.obj)):
                 obj = context.obj[i]
-                charCount = obj.text.characterCount
+                text = obj.queryText()
+                charCount = text.characterCount
                 if offset > charCount:
                     offset -= charCount
                 else:
-                    obj.text.setCaretOffset(offset)
+                    text.setCaretOffset(offset)
                     break
         elif type == speechserver.SayAllContext.COMPLETED:
             #print "COMPLETED", context.utterance, context.currentOffset
             obj = context.obj[len(context.obj)-1]
-            obj.text.setCaretOffset(context.currentOffset)
+            obj.queryText().setCaretOffset(context.currentOffset)
             orca.setLocusOfFocus(None, obj, False)
 
     def textLines(self, obj):
@@ -146,11 +146,10 @@ class Script(default.Script):
         [SayAllContext, acss], where SayAllContext has the text to be
         spoken and acss is an ACSS instance for speaking the text.
         """
-        if not obj:
-            return
 
-        text = obj.text
-        if not text:
+        try:
+            text = obj.queryText()
+        except:
             return
 
         length = text.characterCount
@@ -158,22 +157,21 @@ class Script(default.Script):
         string = ""
         textObjs = []
         textObjs.append(obj)
-        startOffset = obj.text.caretOffset
+        startOffset = text.caretOffset
 
         # Determine the correct "say all by" mode to use.
         #        
         if settings.sayAllStyle == settings.SAYALL_STYLE_SENTENCE:
-            mode = atspi.Accessibility.TEXT_BOUNDARY_SENTENCE_END
+            mode = pyatspi.TEXT_BOUNDARY_SENTENCE_END
         elif settings.sayAllStyle == settings.SAYALL_STYLE_LINE:
-            mode = atspi.Accessibility.TEXT_BOUNDARY_LINE_START
+            mode = pyatspi.TEXT_BOUNDARY_LINE_START
         else:
-            mode = atspi.Accessibility.TEXT_BOUNDARY_LINE_START
+            mode = pyatspi.TEXT_BOUNDARY_LINE_START
 
         # Get the next line of text to read
         #
         done = False
         while not done:
-            lastEndOffset = -1
             while offset < length:
                 [mystr, start, end] = text.getTextAtOffset(offset, mode)
                 endOffset = end
@@ -181,7 +179,7 @@ class Script(default.Script):
                 if len(mystr) != 0:
                     string += mystr
 
-                if mode == atspi.Accessibility.TEXT_BOUNDARY_LINE_START or \
+                if mode == pyatspi.TEXT_BOUNDARY_LINE_START or \
                    len(mystr) == 0 or mystr[len(mystr)-1] in '.?!':
                     string = self.adjustForRepeats(string)
                     if string.isupper():
@@ -201,16 +199,15 @@ class Script(default.Script):
                     offset = end
 
             moreLines = False
-            relations = obj.relations
+            relations = obj.getRelationSet()
             for relation in relations:
                 if relation.getRelationType()  \
-                       == atspi.Accessibility.RELATION_FLOWS_TO:
-                    obj = atspi.Accessible.makeAccessible(relation.getTarget(0))
-
-                    text = obj.text
-                    if not text:
+                       == pyatspi.RELATION_FLOWS_TO:
+                    obj = relation.getTarget(0)
+                    try:
+                        text = obj.queryText()
+                    except:
                         return
-
                     textObjs.append(obj)
                     length = text.characterCount
                     offset = 0
@@ -255,7 +252,7 @@ class Script(default.Script):
         # Spelling dialog. Look for the one that isn't a label to
         # another component.
         #
-        allLabels = self.findByRole(panel, rolenames.ROLE_LABEL)
+        allLabels = self.findByRole(panel, pyatspi.ROLE_LABEL)
         for label in allLabels:
             # Translators: these are labels from the gedit spell checking
             # dialog and must be the same strings gedit uses.  We hate
@@ -276,8 +273,8 @@ class Script(default.Script):
         # was called. If they are the same then we ignore it.
 
         if self.textArea != None:
-            allText = self.findByRole(self.textArea, rolenames.ROLE_TEXT)
-            caretPosition = allText[0].text.caretOffset
+            allText = self.findByRole(self.textArea, pyatspi.ROLE_TEXT)
+            caretPosition = allText[0].queryText().caretOffset
 
             debug.println(self.debugLevel, \
                 "gedit.readMisspeltWord: type=%s  word=%s caret position=%d" \
@@ -328,28 +325,30 @@ class Script(default.Script):
         """
 
         obj = orca_state.locusOfFocus
-        rolesList1 = [rolenames.ROLE_PUSH_BUTTON,
-                     rolenames.ROLE_FILLER,
-                     rolenames.ROLE_FILLER,
-                     rolenames.ROLE_DIALOG,
-                     rolenames.ROLE_APPLICATION]
+        rolesList1 = [pyatspi.ROLE_PUSH_BUTTON,
+                      pyatspi.ROLE_FILLER,
+                      pyatspi.ROLE_FILLER,
+                      pyatspi.ROLE_DIALOG,
+                      pyatspi.ROLE_APPLICATION]
 
-        rolesList2 = [rolenames.ROLE_COMBO_BOX,
-                     rolenames.ROLE_PANEL,
-                     rolenames.ROLE_FILLER,
-                     rolenames.ROLE_FILLER,
-                     rolenames.ROLE_DIALOG,
-                     rolenames.ROLE_APPLICATION]
+        rolesList2 = [pyatspi.ROLE_TEXT,
+                      pyatspi.ROLE_COMBO_BOX,
+                      pyatspi.ROLE_PANEL,
+                      pyatspi.ROLE_FILLER,
+                      pyatspi.ROLE_FILLER,
+                      pyatspi.ROLE_DIALOG,
+                      pyatspi.ROLE_APPLICATION]
 
         # Translators: this is used to tell us if the focus is on the
         # "Find" button in gedit's Find dialog.  It must match what
         # gedit is using.  We hate keying off stuff like this, but
         # we're forced to do so in this case.
         #
+        tmp = obj.parent.parent
         if (self.isDesiredFocusedItem(obj, rolesList1) \
             and obj.name == _("Find")) \
             or (self.isDesiredFocusedItem(obj, rolesList2) \
-                and obj.parent.parent.parent.parent.name == _("Find")):
+                and tmp.parent.parent.parent.name == _("Find")):
             return True
         else:
             return False
@@ -367,12 +366,9 @@ class Script(default.Script):
         - newLocusOfFocus: Accessible that is the new locus of focus
         """
 
-        brailleGen = self.brailleGenerator
-        speechGen = self.speechGenerator
-
         debug.printObjectEvent(self.debugLevel,
                                event,
-                               event.source.toString())
+                               debug.getAccessibleDetails(event.source))
 
         # self.printAncestry(event.source)
 
@@ -386,12 +382,12 @@ class Script(default.Script):
         # Note that this drops through to then use the default event
         # processing in the parent class for this "focus:" event.
 
-        rolesList = [rolenames.ROLE_TEXT,
-                     rolenames.ROLE_SCROLL_PANE,
-                     rolenames.ROLE_FILLER,
-                     rolenames.ROLE_PAGE_TAB,
-                     rolenames.ROLE_PAGE_TAB_LIST,
-                     rolenames.ROLE_SPLIT_PANE]
+        rolesList = [pyatspi.ROLE_TEXT,
+                     pyatspi.ROLE_SCROLL_PANE,
+                     pyatspi.ROLE_FILLER,
+                     pyatspi.ROLE_PAGE_TAB,
+                     pyatspi.ROLE_PAGE_TAB_LIST,
+                     pyatspi.ROLE_SPLIT_PANE]
         if self.isDesiredFocusedItem(event.source, rolesList):
             debug.println(self.debugLevel,
                           "gedit.locusOfFocusChanged - text area.")
@@ -411,13 +407,14 @@ class Script(default.Script):
         # their translation of this string matches what gedit uses in
         # that locale.
 
-        rolesList = [rolenames.ROLE_TEXT,
-                     rolenames.ROLE_FILLER,
-                     rolenames.ROLE_PANEL,
-                     rolenames.ROLE_FILLER,
-                     rolenames.ROLE_FRAME]
+        rolesList = [pyatspi.ROLE_TEXT,
+                     pyatspi.ROLE_FILLER,
+                     pyatspi.ROLE_PANEL,
+                     pyatspi.ROLE_FILLER,
+                     pyatspi.ROLE_FRAME]
         if self.isDesiredFocusedItem(event.source, rolesList):
-            frame = event.source.parent.parent.parent.parent
+            tmp = event.source.parent.parent
+            frame = tmp.parent.parent
             # Translators: this is the name of the "Check Spelling" window
             # in gedit and must be the same as what gedit uses.  We hate
             # keying off stuff like this, but we're forced to do so in this
@@ -447,12 +444,9 @@ class Script(default.Script):
         - event: the Event
         """
 
-        brailleGen = self.brailleGenerator
-        speechGen = self.speechGenerator
-
         debug.printObjectEvent(self.debugLevel,
                                event,
-                               event.source.toString())
+                               debug.getAccessibleDetails(event.source))
 
         # self.printAncestry(event.source)
 
@@ -471,10 +465,10 @@ class Script(default.Script):
         # their translation of this string matches what gedit uses in
         # that locale.
 
-        rolesList = [rolenames.ROLE_LABEL,
-                     rolenames.ROLE_PANEL,
-                     rolenames.ROLE_FILLER,
-                     rolenames.ROLE_FRAME]
+        rolesList = [pyatspi.ROLE_LABEL,
+                     pyatspi.ROLE_PANEL,
+                     pyatspi.ROLE_FILLER,
+                     pyatspi.ROLE_FRAME]
         if self.isDesiredFocusedItem(event.source, rolesList):
             frame = event.source.parent.parent.parent
             # Translators: this is the name of the "Check Spelling" window
@@ -506,14 +500,14 @@ class Script(default.Script):
         # keying off stuff like this, but we're forced to do so in this
         # case.
         #
-        if event.source.role == rolenames.ROLE_STATUSBAR \
+        if event.source.getRole() == pyatspi.ROLE_STATUS_BAR \
            and self.isFocusOnFindDialog() \
            and orca_state.lastNonModifierKeyEvent.event_string == "Return" \
            and event.source.name == _("Phrase not found"):
-                debug.println(self.debugLevel,
-                              "gedit.onNameChanged - phrase not found.")
+            debug.println(self.debugLevel,
+                          "gedit.onNameChanged - phrase not found.")
 
-                speech.speak(event.source.name)
+            speech.speak(event.source.name)
 
         # Pass the event onto the parent class to be handled in the default way.
         default.Script.onNameChanged(self, event)
@@ -551,7 +545,7 @@ class Script(default.Script):
 
         debug.printObjectEvent(self.debugLevel,
                                event,
-                               event.source.toString())
+                               debug.getAccessibleDetails(event.source))
 
         # self.printAncestry(event.source)
 
@@ -565,9 +559,9 @@ class Script(default.Script):
         if self.isFocusOnFindDialog() \
            and orca_state.lastNonModifierKeyEvent.event_string == "Return":
             debug.println(self.debugLevel, "gedit.onCaretMoved - find dialog.")
-
-            allComboBoxes = self.findByRole(orca_state.locusOfFocus.app,
-                                            rolenames.ROLE_COMBO_BOX)
+            allComboBoxes = \
+                     self.findByRole(orca_state.locusOfFocus.getApplication(),
+                                     pyatspi.ROLE_COMBO_BOX)
             phrase = self.getDisplayedText(allComboBoxes[0])
             [text, caretOffset, startOffset] = \
                 self.getTextLineAtCaret(event.source)
