@@ -25,18 +25,14 @@ __date__      = "$Date:$"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
+import pyatspi
+
 import orca.debug as debug
 import orca.default as default
-import orca.atspi as atspi
 import orca.input_event as input_event
-import orca.debug as debug
 import orca.keybindings as keybindings
-import orca.rolenames as rolenames
-import orca.braille as braille
 import orca.orca_state as orca_state
 import orca.speech as speech
-import orca.settings as settings
-import orca.util as util
 
 from orca.orca_i18n import _ # for gettext support
 
@@ -97,14 +93,16 @@ class Script(default.Script):
         """
         # Set the debug level for all the methods in this script.
         #
-        self.debugLevel=debug.LEVEL_FINEST
+        self.debugLevel = debug.LEVEL_FINEST
 
-        self.MESSAGE_LIST_LENGTH=10
-        self.previousMessages=RingList(self.MESSAGE_LIST_LENGTH)
+        self.MESSAGE_LIST_LENGTH = 10
+        self.previousMessages = RingList(self.MESSAGE_LIST_LENGTH)
 
-        #Initially populate the cyclic list with empty strings
-        for i in range(0, self.previousMessages.maxsize()):
-           self.previousMessages.append("")
+        # Initially populate the cyclic list with empty strings
+        i = 0
+        while i < self.previousMessages.maxsize():
+            self.previousMessages.append("")
+            i += 1
 
         default.Script.__init__(self, app)
 
@@ -116,8 +114,8 @@ class Script(default.Script):
         self.inputEventHandlers["readPreviousMessageHandler"] = \
             input_event.InputEventHandler(
                 Script.readPreviousMessage,
-                _("Read the latest n messages in the incoming messages text \
-                    area."))
+                _('Read the latest n messages in the incoming messages text '
+                  'area.'))
 
     def getKeyBindings(self):
 
@@ -132,8 +130,8 @@ class Script(default.Script):
             keyBindings.add(
                 keybindings.KeyBinding(
                     messageKeys[i],
-                    1 << atspi.Accessibility.MODIFIER_ALT,
-                    1 << atspi.Accessibility.MODIFIER_ALT,
+                    1 << pyatspi.MODIFIER_ALT,
+                    1 << pyatspi.MODIFIER_ALT,
                     self.inputEventHandlers["readPreviousMessageHandler"]))
 
         return keyBindings
@@ -145,11 +143,11 @@ class Script(default.Script):
         debug.println(self.debugLevel, "gnome-mud.readPreviousMessage.")
 
         if inputEvent.event_string == "0":
-           inputEvent.event_string="10"
+            inputEvent.event_string = "10"
         i = int(inputEvent.event_string)
         messageNo = self.MESSAGE_LIST_LENGTH-i
      
-        text=""
+        text = ""
         messages = self.previousMessages.get()
         for i in range (messageNo, self.MESSAGE_LIST_LENGTH):
             message = messages[i]
@@ -160,22 +158,22 @@ class Script(default.Script):
 
     def onTextInserted(self, event):
 
-        rolesList=[rolenames.ROLE_TERMINAL,
-                   rolenames.ROLE_FILLER]
         #Whenever a new text is inserted in the incoming message text area,
         #We want to speak and add it to the ringList structure only those lines
         #that contain some text and if the application is the current
         #locusOfFocus. 
-        if util.isDesiredFocusedItem(event.source, rolesList):
+        rolesList = [pyatspi.ROLE_TERMINAL,
+                     pyatspi.ROLE_FILLER]
+        if self.isDesiredFocusedItem(event.source, rolesList):
             if self.flatReviewContext:
                 self.toggleFlatReviewMode()
-            message=event.any_data
+            message = event.any_data
             if message and (not message.isspace()) and message != "\n":
                 debug.println(debug.LEVEL_FINEST, \
                     message + " inserted in ringlist:")
                 self.previousMessages.append(message)
-                if event.source.app == orca_state.locusOfFocus.app:
+                if event.source.getApplication() == \
+                   orca_state.locusOfFocus.getApplication():
                     speech.speak(message)
-
         else:
             default.Script.onTextInserted(self, event)
