@@ -19,9 +19,9 @@
 
 """Custom script for gnome-search-tool"""
 
-__id__        = "$Id: gnome-search-tool.py 3153 2007-10-22 19:18:04Z eitani $"
-__version__   = "$Revision: 3153 $"
-__date__      = "$Date: 2007-10-22 15:18:04 -0400 (Mon, 22 Oct 2007) $"
+__id__        = "$Id: gnome-search-tool.py 3230 2007-11-09 17:02:46Z richb $"
+__version__   = "$Revision: 3230 $"
+__date__      = "$Date: 2007-11-09 12:02:46 -0500 (Fri, 09 Nov 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -101,7 +101,7 @@ class Script(default.Script):
 
         debug.printObjectEvent(self.debugLevel,
                                event,
-                               event.source)
+                               debug.getAccessibleDetails(event.source))
 
         # self.printAncestry(event.source)
 
