@@ -21,9 +21,9 @@
 fallback to local settings if the user settings doesn't exist (e.g., in the
 case of gdm) or doesn't have the specified attribute."""
 
-__id__        = "$Id: settings.py 2811 2007-09-10 22:40:26Z wwalker $"
-__version__   = "$Revision: 2811 $"
-__date__      = "$Date: 2007-09-10 18:40:26 -0400 (Mon, 10 Sep 2007) $"
+__id__        = "$Id: settings.py 3223 2007-11-06 21:52:20Z richb $"
+__version__   = "$Revision: 3223 $"
+__date__      = "$Date: 2007-11-06 16:52:20 -0500 (Tue, 06 Nov 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -99,6 +99,7 @@ userCustomizableSettings = [
     "enableLockingKeys",
     "enableFunctionKeys",
     "enableActionKeys",
+    "enableNavigationKeys",
     "enableBraille",
     "enableBrailleGrouping",
     "brailleVerbosityLevel",
@@ -147,9 +148,9 @@ mainWindowModule = "orca_gui_main"
 # Orca preferences.  Each module is expected to have the method,
 # showPreferencesUI, which will prompt the user for preferences.
 #
-guiPreferencesModule    = "orca_gui_prefs"
-consolePreferencesModule= "orca_console_prefs"
-appGuiPreferencesModule = "app_gui_prefs"
+guiPreferencesModule     = "orca_gui_prefs"
+consolePreferencesModule = "orca_console_prefs"
+appGuiPreferencesModule  = "app_gui_prefs"
 
 # The name of the module that hold the user interface for quitting Orca.
 # This module is expected to have the method, showQuitUI, which will
@@ -252,7 +253,9 @@ silenceSpeech           = False
 # Settings that apply to the particular speech engine to
 # use as well details on the default voices to use.
 #
-speechFactoryModules    = ["espeechfactory","gnomespeechfactory","speechdispatcherfactory"]
+speechFactoryModules    = ["espeechfactory", \
+                           "gnomespeechfactory", \
+                           "speechdispatcherfactory"]
 speechServerFactory     = "gnomespeechfactory"
 speechServerInfo        = None # None means let the factory decide.
 
@@ -390,6 +393,10 @@ enableFunctionKeys      = True
 #
 enableActionKeys        = True
 
+# If True and key echo is enabled, echo Navigation keys.
+#
+enableNavigationKeys    = False
+
 # If True, show the main Orca window.
 #
 showMainWindow          = True
@@ -523,7 +530,8 @@ commFailureAttemptLimit = 5
 #
 # http://mail.python.org/pipermail/python-list/2002-October/126632.html
 # http://twistedmatrix.com/pipermail/twisted-python/2005-July/011052.html
-# http://www.pyzine.com/Issue001/Section_Articles/article_ThreadingGlobalInterpreter.html
+# http://www.pyzine.com/Issue001/Section_Articles/ \
+#                                 article_ThreadingGlobalInterpreter.html
 #
 gilSleepTime            = 0.00001
 
@@ -743,3 +751,7 @@ setScriptMapping(re.compile(_('vte')), "gnome-terminal")
 # supporting pidgin, which is the new name for gaim.
 #
 setScriptMapping(re.compile(_('pidgin')), "gaim")
+
+# Show deprecated messeges in debug output.
+# Set this to True to help find potential pyatspi porting problems
+deprecatedMessages = False
