@@ -23,15 +23,13 @@ class.  For those wishing to override the speech generators, however,
 one can create a new instance and replace/extend the speech generators
 as they see fit."""
 
-__id__        = "$Id: speechgenerator.py 2796 2007-09-06 18:12:59Z shaeger $"
-__version__   = "$Revision: 2796 $"
-__date__      = "$Date: 2007-09-06 14:12:59 -0400 (Thu, 06 Sep 2007) $"
+__id__        = "$Id: speechgenerator.py 3222 2007-11-06 20:38:59Z richb $"
+__version__   = "$Revision: 3222 $"
+__date__      = "$Date: 2007-11-06 15:38:59 -0500 (Tue, 06 Nov 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
-import math
-
-import atspi
+import pyatspi
 import debug
 import orca_state
 import rolenames
@@ -58,103 +56,99 @@ class SpeechGenerator:
         # that generate speech for objects that implement that role.
         #
         self.speechGenerators = {}
-        self.speechGenerators[rolenames.ROLE_ALERT]               = \
+        self.speechGenerators[pyatspi.ROLE_ALERT]               = \
              self._getSpeechForAlert
-        self.speechGenerators[rolenames.ROLE_ANIMATION]           = \
+        self.speechGenerators[pyatspi.ROLE_ANIMATION]           = \
              self._getSpeechForAnimation
-        self.speechGenerators[rolenames.ROLE_ARROW]               = \
+        self.speechGenerators[pyatspi.ROLE_ARROW]               = \
              self._getSpeechForArrow
-        self.speechGenerators[rolenames.ROLE_CHECK_BOX]           = \
+        self.speechGenerators[pyatspi.ROLE_CHECK_BOX]           = \
              self._getSpeechForCheckBox
-        self.speechGenerators[rolenames.ROLE_CHECK_MENU]          = \
+        self.speechGenerators[pyatspi.ROLE_CHECK_MENU_ITEM]     = \
              self._getSpeechForCheckMenuItem
-        self.speechGenerators[rolenames.ROLE_CHECK_MENU_ITEM]     = \
-             self._getSpeechForCheckMenuItem
-        self.speechGenerators[rolenames.ROLE_COLUMN_HEADER]       = \
+        self.speechGenerators[pyatspi.ROLE_COLUMN_HEADER]       = \
              self._getSpeechForColumnHeader
-        self.speechGenerators[rolenames.ROLE_COMBO_BOX]           = \
+        self.speechGenerators[pyatspi.ROLE_COMBO_BOX]           = \
              self._getSpeechForComboBox
-        self.speechGenerators[rolenames.ROLE_DESKTOP_ICON]        = \
+        self.speechGenerators[pyatspi.ROLE_DESKTOP_ICON]        = \
              self._getSpeechForDesktopIcon
-        self.speechGenerators[rolenames.ROLE_DIAL]                = \
+        self.speechGenerators[pyatspi.ROLE_DIAL]                = \
              self._getSpeechForDial
-        self.speechGenerators[rolenames.ROLE_DIALOG]              = \
+        self.speechGenerators[pyatspi.ROLE_DIALOG]              = \
              self._getSpeechForDialog
-        self.speechGenerators[rolenames.ROLE_DIRECTORY_PANE]      = \
+        self.speechGenerators[pyatspi.ROLE_DIRECTORY_PANE]      = \
              self._getSpeechForDirectoryPane
-        self.speechGenerators[rolenames.ROLE_FRAME]               = \
+        self.speechGenerators[pyatspi.ROLE_FRAME]               = \
              self._getSpeechForFrame
-        self.speechGenerators[rolenames.ROLE_HTML_CONTAINER]      = \
+        self.speechGenerators[pyatspi.ROLE_HTML_CONTAINER]      = \
              self._getSpeechForHtmlContainer
-        self.speechGenerators[rolenames.ROLE_ICON]                = \
+        self.speechGenerators[pyatspi.ROLE_ICON]                = \
              self._getSpeechForIcon
-        self.speechGenerators[rolenames.ROLE_IMAGE]               = \
+        self.speechGenerators[pyatspi.ROLE_IMAGE]               = \
              self._getSpeechForImage
-        self.speechGenerators[rolenames.ROLE_LABEL]               = \
+        self.speechGenerators[pyatspi.ROLE_LABEL]               = \
              self._getSpeechForLabel
-        self.speechGenerators[rolenames.ROLE_LAYERED_PANE]        = \
+        self.speechGenerators[pyatspi.ROLE_LAYERED_PANE]        = \
              self._getSpeechForLayeredPane
-        self.speechGenerators[rolenames.ROLE_LIST]                = \
+        self.speechGenerators[pyatspi.ROLE_LIST]                = \
              self._getSpeechForList
-        self.speechGenerators[rolenames.ROLE_MENU]                = \
+        self.speechGenerators[pyatspi.ROLE_MENU]                = \
              self._getSpeechForMenu
-        self.speechGenerators[rolenames.ROLE_MENU_BAR]            = \
+        self.speechGenerators[pyatspi.ROLE_MENU_BAR]            = \
              self._getSpeechForMenuBar
-        self.speechGenerators[rolenames.ROLE_MENU_ITEM]           = \
+        self.speechGenerators[pyatspi.ROLE_MENU_ITEM]           = \
              self._getSpeechForMenuItem
-        self.speechGenerators[rolenames.ROLE_OPTION_PANE]         = \
+        self.speechGenerators[pyatspi.ROLE_OPTION_PANE]         = \
              self._getSpeechForOptionPane
-        self.speechGenerators[rolenames.ROLE_PAGE_TAB]            = \
+        self.speechGenerators[pyatspi.ROLE_PAGE_TAB]            = \
              self._getSpeechForPageTab
-        self.speechGenerators[rolenames.ROLE_PAGE_TAB_LIST]       = \
+        self.speechGenerators[pyatspi.ROLE_PAGE_TAB_LIST]       = \
              self._getSpeechForPageTabList
-        self.speechGenerators[rolenames.ROLE_PARAGRAPH]           = \
+        self.speechGenerators[pyatspi.ROLE_PARAGRAPH]           = \
              self._getSpeechForText
-        self.speechGenerators[rolenames.ROLE_PASSWORD_TEXT]       = \
+        self.speechGenerators[pyatspi.ROLE_PASSWORD_TEXT]       = \
              self._getSpeechForText
-        self.speechGenerators[rolenames.ROLE_PROGRESS_BAR]        = \
+        self.speechGenerators[pyatspi.ROLE_PROGRESS_BAR]        = \
              self._getSpeechForProgressBar
-        self.speechGenerators[rolenames.ROLE_PUSH_BUTTON]         = \
+        self.speechGenerators[pyatspi.ROLE_PUSH_BUTTON]         = \
              self._getSpeechForPushButton
-        self.speechGenerators[rolenames.ROLE_RADIO_BUTTON]        = \
+        self.speechGenerators[pyatspi.ROLE_RADIO_BUTTON]        = \
              self._getSpeechForRadioButton
-        self.speechGenerators[rolenames.ROLE_RADIO_MENU]          = \
+        self.speechGenerators[pyatspi.ROLE_RADIO_MENU_ITEM]     = \
              self._getSpeechForRadioMenuItem
-        self.speechGenerators[rolenames.ROLE_RADIO_MENU_ITEM]     = \
-             self._getSpeechForRadioMenuItem
-        self.speechGenerators[rolenames.ROLE_ROW_HEADER]          = \
+        self.speechGenerators[pyatspi.ROLE_ROW_HEADER]          = \
              self._getSpeechForRowHeader
-        self.speechGenerators[rolenames.ROLE_SCROLL_BAR]          = \
+        self.speechGenerators[pyatspi.ROLE_SCROLL_BAR]          = \
              self._getSpeechForScrollBar
-        self.speechGenerators[rolenames.ROLE_SLIDER]              = \
+        self.speechGenerators[pyatspi.ROLE_SLIDER]              = \
              self._getSpeechForSlider
-        self.speechGenerators[rolenames.ROLE_SPIN_BUTTON]         = \
+        self.speechGenerators[pyatspi.ROLE_SPIN_BUTTON]         = \
              self._getSpeechForSpinButton
-        self.speechGenerators[rolenames.ROLE_SPLIT_PANE]          = \
+        self.speechGenerators[pyatspi.ROLE_SPLIT_PANE]          = \
              self._getSpeechForSplitPane
-        self.speechGenerators[rolenames.ROLE_TABLE]               = \
+        self.speechGenerators[pyatspi.ROLE_TABLE]               = \
              self._getSpeechForTable
-        self.speechGenerators[rolenames.ROLE_TABLE_CELL]          = \
+        self.speechGenerators[pyatspi.ROLE_TABLE_CELL]          = \
              self._getSpeechForTableCellRow
-        self.speechGenerators[rolenames.ROLE_TABLE_COLUMN_HEADER] = \
+        self.speechGenerators[pyatspi.ROLE_TABLE_COLUMN_HEADER] = \
              self._getSpeechForTableColumnHeader
-        self.speechGenerators[rolenames.ROLE_TABLE_ROW_HEADER]    = \
+        self.speechGenerators[pyatspi.ROLE_TABLE_ROW_HEADER]    = \
              self._getSpeechForTableRowHeader
-        self.speechGenerators[rolenames.ROLE_TEAR_OFF_MENU_ITEM]  = \
+        self.speechGenerators[pyatspi.ROLE_TEAROFF_MENU_ITEM]  = \
              self._getSpeechForMenu
-        self.speechGenerators[rolenames.ROLE_TERMINAL]            = \
+        self.speechGenerators[pyatspi.ROLE_TERMINAL]            = \
              self._getSpeechForTerminal
-        self.speechGenerators[rolenames.ROLE_TEXT]                = \
+        self.speechGenerators[pyatspi.ROLE_TEXT]                = \
              self._getSpeechForText
-        self.speechGenerators[rolenames.ROLE_TOGGLE_BUTTON]       = \
+        self.speechGenerators[pyatspi.ROLE_TOGGLE_BUTTON]       = \
              self._getSpeechForToggleButton
-        self.speechGenerators[rolenames.ROLE_TOOL_BAR]            = \
+        self.speechGenerators[pyatspi.ROLE_TOOL_BAR]            = \
              self._getSpeechForToolBar
-        self.speechGenerators[rolenames.ROLE_TREE]                = \
+        self.speechGenerators[pyatspi.ROLE_TREE]                = \
              self._getSpeechForTable
-        self.speechGenerators[rolenames.ROLE_TREE_TABLE]          = \
+        self.speechGenerators[pyatspi.ROLE_TREE_TABLE]          = \
              self._getSpeechForTable
-        self.speechGenerators[rolenames.ROLE_WINDOW]              = \
+        self.speechGenerators[pyatspi.ROLE_WINDOW]              = \
              self._getSpeechForWindow
 
     def _getSpeechForObjectAccelerator(self, obj):
@@ -195,7 +189,8 @@ class SpeechGenerator:
 
         Returns a list of utterances to be spoken.
         """
-        if obj.state.count(atspi.Accessibility.STATE_SENSITIVE) == 0:
+        state = obj.getState()
+        if not state.contains(pyatspi.STATE_SENSITIVE):
             # Translators: this represents an item on the screen that has
             # been set insensitive (or grayed out).
             #
@@ -219,9 +214,9 @@ class SpeechGenerator:
         else:
             return []
 
-    def _getSpeechForObjectRole(self, obj):
-        if (obj.role != rolenames.ROLE_UNKNOWN):
-            return [rolenames.getSpeechForRoleName(obj)]
+    def _getSpeechForObjectRole(self, obj, role=None):
+        if (obj.getRole() != pyatspi.ROLE_UNKNOWN):
+            return [rolenames.getSpeechForRoleName(obj, role)]
         else:
             return []
 
@@ -240,7 +235,7 @@ class SpeechGenerator:
         debug.println(debug.LEVEL_FINER,
                       "           obj             = %s" % obj.name)
         debug.println(debug.LEVEL_FINER,
-                      "           role            = %s" % obj.role)
+                      "           role            = %s" % obj.getRoleName())
         debug.println(debug.LEVEL_FINER,
                       "           already_focused = %s" % already_focused)
         debug.println(debug.LEVEL_FINER,
@@ -249,7 +244,7 @@ class SpeechGenerator:
             debug.println(debug.LEVEL_FINER,
                       "               (%s)" % text)
 
-    def _getDefaultSpeech(self, obj, already_focused):
+    def _getDefaultSpeech(self, obj, already_focused, role=None):
         """Gets a list of utterances to be spoken for the current
         object's name, role, and any accelerators.  This is usually the
         fallback speech generator should no other specialized speech
@@ -262,6 +257,8 @@ class SpeechGenerator:
         Arguments:
         - obj: an Accessible
         - already_focused: False if object just received focus
+        - role: A role that should be used instead of the Accessible's 
+          possible role.
 
         Returns a list of utterances to be spoken for the object.
         """
@@ -274,7 +271,7 @@ class SpeechGenerator:
             name = self._getSpeechForObjectName(obj)
             if name != label:
                 utterances.extend(name)
-            utterances.extend(self._getSpeechForObjectRole(obj))
+            utterances.extend(self._getSpeechForObjectRole(obj, role))
 
         utterances.extend(self._getSpeechForObjectAvailability(obj))
 
@@ -375,7 +372,8 @@ class SpeechGenerator:
         """
 
         utterances = []
-        if obj.state.count(atspi.Accessibility.STATE_CHECKED):
+        state = obj.getState()
+        if state.contains(pyatspi.STATE_CHECKED):
             # Translators: this represents the state of a checkbox.
             #
             checkedState = _("checked")
@@ -392,7 +390,12 @@ class SpeechGenerator:
             name = self._getSpeechForObjectName(obj)
             if name != label:
                 utterances.extend(name)
-            utterances.extend(self._getSpeechForObjectRole(obj))
+            if obj.getRole() == pyatspi.ROLE_TABLE_CELL:
+                utterances.extend(
+                  self._getSpeechForObjectRole(
+                    obj, pyatspi.ROLE_CHECK_BOX))
+            else:
+                utterances.extend(self._getSpeechForObjectRole(obj))
             utterances.append(checkedState)
             utterances.extend(self._getSpeechForObjectAvailability(obj))
         else:
@@ -628,14 +631,20 @@ class SpeechGenerator:
         name = self._getSpeechForObjectName(obj)
         if name != label:
             utterances.extend(name)
-
-        if obj.image:
-            description = obj.image.imageDescription
+        
+        try:
+            image = obj.queryImage()
+        except NotImplementedError:
+            pass
+        else:
+            description = image.imageDescription
             if description and len(description):
                 utterances.append(description)
 
         if settings.speechVerbosityLevel == settings.VERBOSITY_LEVEL_VERBOSE:
-            utterances.append(rolenames.getSpeechForRoleName(obj))
+            utterances.append(
+              rolenames.getSpeechForRoleName(
+                obj, pyatspi.ROLE_ICON))
 
         self._debugGenerator("_getSpeechForIcon",
                              obj,
@@ -654,7 +663,8 @@ class SpeechGenerator:
         Returns a list of utterances to be spoken for the object.
         """
 
-        utterances = self._getDefaultSpeech(obj, already_focused)
+        utterances = self._getDefaultSpeech(
+            obj, already_focused, pyatspi.ROLE_IMAGE)
 
         self._debugGenerator("_getSpeechForImage",
                              obj,
@@ -702,9 +712,9 @@ class SpeechGenerator:
         # If this has no children, then let the user know.
         #
         hasItems = False
-        for i in range(0, obj.childCount):
-            child = obj.child(i)
-            if child.state.count(atspi.Accessibility.STATE_SHOWING):
+        for child in obj:
+            state = child.getState()
+            if state.contains(pyatspi.STATE_SHOWING):
                 hasItems = True
                 break
         if not hasItems:
@@ -736,6 +746,40 @@ class SpeechGenerator:
                              utterances)
 
         return utterances
+    
+    def _getSpeechForListItem(self, obj, already_focused):
+        """Get the speech for a listitem.
+
+        Arguments:
+        - obj: the listitem
+        - already_focused: False if object just received focus
+
+        Returns a list of utterances to be spoken for the object.
+        """
+
+        utterances = self._getDefaultSpeech(obj, already_focused)
+
+        # If already in focus then the tree probably collapsed or expanded
+        state = obj.getState()
+        if state.contains(pyatspi.STATE_EXPANDABLE):
+            if state.contains(pyatspi.STATE_EXPANDED):
+                # Translators: this represents the state of a node in a tree.
+                # 'expanded' means the children are showing.
+                # 'collapsed' means the children are not showing.
+                #
+                utterances.append(_("expanded"))
+            else:
+                # Translators: this represents the state of a node in a tree.
+                # 'expanded' means the children are showing.
+                # 'collapsed' means the children are not showing.
+                #
+                utterances.append(_("collapsed"))
+                
+        self._debugGenerator("_getSpeechForListItem",
+                             obj,
+                             already_focused,
+                             utterances)
+        return utterances
 
     def _getSpeechForMenu(self, obj, already_focused):
         """Get the speech for a menu.
@@ -804,7 +848,8 @@ class SpeechGenerator:
         # menu item" that is currently unchecked and speak that state. 
         # See Orca bug #433398 for more details.
         #
-        if obj.state.count(atspi.Accessibility.STATE_CHECKED):
+        state = obj.getState()
+        if state.contains(pyatspi.STATE_CHECKED):
             # Translators: this represents the state of a checked menu item.
             #
             utterances.append(_("checked"))
@@ -835,7 +880,7 @@ class SpeechGenerator:
         if len(utterances) == 0:
             if obj.name and (len(obj.name)):
                 utterances.append(obj.name)
-        if obj.role != rolenames.ROLE_PARAGRAPH:
+        if obj.getRole() != pyatspi.ROLE_PARAGRAPH:
             utterances.extend(self._getSpeechForObjectRole(obj))
 
         [text, caretOffset, startOffset] = self._script.getTextLineAtCaret(obj)
@@ -921,8 +966,9 @@ class SpeechGenerator:
         Returns a list of utterances to be spoken for the object.
         """
 
-        percentValue = (obj.value.currentValue / \
-            (obj.value.maximumValue - obj.value.minimumValue)) * 100.0
+        value = obj.queryValue()
+        percentValue = (value.currentValue / \
+            (value.maximumValue - value.minimumValue)) * 100.0
 
         # Translators: this is the percentage value of a progress bar.
         #
@@ -978,7 +1024,8 @@ class SpeechGenerator:
         """
 
         utterances = []
-        if obj.state.count(atspi.Accessibility.STATE_CHECKED):
+        state = obj.getState()
+        if state.contains(pyatspi.STATE_CHECKED):
             # Translators: this is in reference to a radio button being
             # selected or not.
             #
@@ -1090,46 +1137,25 @@ class SpeechGenerator:
         Returns a list of utterances to be spoken for the object.
         """
 
-        value = obj.value
-
-        # OK, this craziness is all about trying to figure out the most
-        # meaningful formatting string for the floating point values.
-        # The number of places to the right of the decimal point should
-        # be set by the minimumIncrement, but the minimumIncrement isn't
-        # always set.  So...we'll default the minimumIncrement to 1/100
-        # of the range.  But, if max == min, then we'll just go for showing
-        # them off to two meaningful digits.
-        #
-        try:
-            minimumIncrement = value.minimumIncrement
-        except:
-            minimumIncrement = 0.0
-
-        if minimumIncrement == 0.0:
-            minimumIncrement = (value.maximumValue - value.minimumValue) \
-                               / 100.0
-
-        try:
-            decimalPlaces = max(0, -math.log10(minimumIncrement))
-        except:
-            try:
-                decimalPlaces = max(0, -math.log10(value.minimumValue))
-            except:
-                try:
-                    decimalPlaces = max(0, -math.log10(value.maximumValue))
-                except:
-                    decimalPlaces = 0
-
-        formatter = "%%.%df" % decimalPlaces
-        valueString = formatter % value.currentValue
-        #minString   = formatter % value.minimumValue
-        #maxString   = formatter % value.maximumValue
+        valueString = self._script.getTextForValue(obj)
 
         if already_focused:
             utterances = [valueString]
         else:
             utterances = []
             utterances.extend(self._getSpeechForObjectLabel(obj))
+            # Ignore the text on the slider.  See bug 340559
+            # (http://bugzilla.gnome.org/show_bug.cgi?id=340559): the
+            # implementors of the slider support decided to put in a
+            # Unicode left-to-right character as part of the text,
+            # even though that is not painted on the screen.
+            #
+            # In Java, however, there are sliders without a label. In
+            # this case, we'll add to presentation the slider name if
+            # it exists and we haven't found anything yet.
+            #
+            if not utterances:
+                utterances.extend(self._getSpeechForObjectName(obj))
             utterances.extend(self._getSpeechForObjectRole(obj))
             utterances.append(valueString)
             utterances.extend(self._getSpeechForObjectAvailability(obj))
@@ -1174,7 +1200,18 @@ class SpeechGenerator:
         Returns a list of utterances to be spoken for the object.
         """
 
-        utterances = self._getDefaultSpeech(obj, already_focused)
+        valueString = self._script.getTextForValue(obj)
+
+        if already_focused:
+            utterances = [valueString]
+        else:
+            utterances = []
+            utterances.extend(self._getSpeechForObjectLabel(obj))
+            if not utterances:
+                utterances.extend(self._getSpeechForObjectName(obj))
+            utterances.extend(self._getSpeechForObjectRole(obj))
+            utterances.append(valueString)
+            utterances.extend(self._getSpeechForObjectAvailability(obj))
 
         self._debugGenerator("_getSpeechForSplitPane",
                              obj,
@@ -1202,13 +1239,7 @@ class SpeechGenerator:
 
         # If this is a table with no children, then let the user know.
         #
-        hasItems = False
-        for i in range(0, obj.childCount):
-            child = obj.child(i)
-            if child and child.state.count(atspi.Accessibility.STATE_SHOWING):
-                hasItems = True
-                break
-        if not hasItems:
+        if not obj.childCount:
             # Translators: this is the number of items in a layered pane
             # or table.
             #
@@ -1228,21 +1259,6 @@ class SpeechGenerator:
 
         utterances = []
 
-        # Check to see if this table cell contains an icon (image).
-        # If yes:
-        #   1/ Try to get a description for it and speak that. 
-        #   2/ Treat the object of role type ROLE_IMAGE and speak 
-        #      the role name.
-        # See bug #465989 for more details.
-        #
-        if obj.image:
-            if obj.image.imageDescription:
-                utterances.append(obj.image.imageDescription)
-            obj.role = rolenames.ROLE_IMAGE
-            utterances.extend(self._getSpeechForImage(obj, already_focused))
-            obj.role = rolenames.ROLE_TABLE_CELL
-            return utterances
-
         # If this table cell has 2 children and one of them has a 
         # 'toggle' action and the other does not, then present this 
         # as a checkbox where:
@@ -1253,9 +1269,12 @@ class SpeechGenerator:
         if obj.childCount == 2:
             cellOrder = []
             hasToggle = [ False, False ]
-            for i in range(0, obj.childCount):
-                action = obj.child(i).action
-                if action:
+            for i, child in enumerate(obj):
+                try:
+                    action = child.queryAction()
+                except NotImplementedError:
+                    continue
+                else:
                     for j in range(0, action.nActions):
                         if action.getName(j) == "toggle":
                             hasToggle[i] = True
@@ -1274,8 +1293,8 @@ class SpeechGenerator:
                         pass
                     else:
                         utterances.extend( \
-                            self._getSpeechForTableCell(obj.child(i),
-                                                              already_focused))
+                            self._getSpeechForTableCell(obj[i],
+                                                        already_focused))
                 return utterances
 
         # [[[TODO: WDW - Attempt to infer the cell type.  There's a
@@ -1283,24 +1302,47 @@ class SpeechGenerator:
         # state, check the NODE_CHILD_OF relation, etc.  Logged as
         # bugzilla bug 319750.]]]
         #
-        action = obj.action
+        try:
+            action = obj.queryAction()
+        except NotImplementedError:
+            action = None
         if action:
             for i in range(0, action.nActions):
                 debug.println(debug.LEVEL_FINEST,
                     "speechgenerator.__getTableCellUtterances " \
                     + "looking at action %d" % i)
                 if action.getName(i) == "toggle":
-                    obj.role = rolenames.ROLE_CHECK_BOX
                     utterances = self._getSpeechForCheckBox(obj,
                                                             already_focused)
-                    obj.role = rolenames.ROLE_TABLE_CELL
                     break
 
-        utterances.append(self._script.getDisplayedText(\
-                          self._script.getRealActiveDescendant(obj)))
+        displayedText = self._script.getDisplayedText( \
+                          self._script.getRealActiveDescendant(obj))
+        if not already_focused:
+            utterances.append(displayedText)
 
-        if obj.state.count(atspi.Accessibility.STATE_EXPANDABLE):
-            if obj.state.count(atspi.Accessibility.STATE_EXPANDED):
+        # If there is no displayed text, check to see if this table cell 
+        # contains an icon (image). If yes:
+        #   1/ Try to get a description for it and speak that.
+        #   2/ Treat the object of role type ROLE_IMAGE and speak
+        #      the role name.
+        # See bug #465989 for more details.
+        #
+        # [[TODO: eitani - incorprate this in new rolenames ]]
+        try:
+            image = obj.queryImage()
+        except:
+            image = None
+
+        if (not displayedText or len(displayedText) == 0) and image:
+            if not already_focused:
+                if image.imageDescription:
+                    utterances.append(image.imageDescription)
+                utterances.extend(self._getSpeechForImage(obj, already_focused))
+
+        state = obj.getState()
+        if state.contains(pyatspi.STATE_EXPANDABLE):
+            if state.contains(pyatspi.STATE_EXPANDED):
                 # Translators: this represents the state of a node in a tree.
                 # 'expanded' means the children are showing.
                 # 'collapsed' means the children are not showing.
@@ -1347,11 +1389,15 @@ class SpeechGenerator:
         utterances = []
 
         if (not already_focused):
-            if settings.readTableCellRow and obj.parent.table \
+            try:
+                parent_table = obj.parent.queryTable()
+            except NotImplementedError:
+                parent_table = None
+            if settings.readTableCellRow and parent_table \
                 and (not self._script.isLayoutOnly(obj.parent)):
                 parent = obj.parent
-                row = parent.table.getRowAtIndex(obj.index)
-                column = parent.table.getColumnAtIndex(obj.index)
+                row = parent_table.getRowAtIndex(obj.getIndexInParent())
+                column = parent_table.getColumnAtIndex(obj.getIndexInParent())
 
                 # This is an indication of whether we should speak all the
                 # table cells (the user has moved focus up or down a row),
@@ -1359,18 +1405,18 @@ class SpeechGenerator:
                 # the same row).
                 #
                 speakAll = True
-                if parent.__dict__.has_key("lastRow") and \
-                    parent.__dict__.has_key("lastColumn"):
-                    speakAll = (parent.lastRow != row) or \
-                           ((row == 0 or row == parent.table.nRows-1) and \
-                            parent.lastColumn == column)
+                if self._script.pointOfReference.has_key("lastRow") and \
+                    self._script.pointOfReference.has_key("lastColumn"):
+                    pointOfReference = self._script.pointOfReference
+                    speakAll = (pointOfReference["lastRow"] != row) or \
+                        ((row == 0 or row == parent_table.nRows-1) and \
+                           pointOfReference["lastColumn"] == column)
 
                 if speakAll:
-                    for i in range(0, parent.table.nColumns):
-                        accRow = parent.table.getAccessibleAt(row, i)
-                        cell = atspi.Accessible.makeAccessible(accRow)
-                        showing = cell.state.count( \
-                                          atspi.Accessibility.STATE_SHOWING)
+                    for i in range(0, parent_table.nColumns):
+                        cell = parent_table.getAccessibleAt(row, i)
+                        state = cell.getState()
+                        showing = state.contains(pyatspi.STATE_SHOWING)
                         if showing:
                             # If this table cell has a "toggle" action, and
                             # doesn't have any label associated with it then 
@@ -1379,12 +1425,15 @@ class SpeechGenerator:
                             #
                             label = self._script.getDisplayedText( \
                                 self._script.getRealActiveDescendant(cell))
-                            action = cell.action
+                            try:
+                                action = cell.queryAction()
+                            except NotImplementedError:
+                                action = None
                             if action and (label == None or len(label) == 0):
                                 for j in range(0, action.nActions):
                                     if action.getName(j) == "toggle":
-                                        header = parent.table.getColumnHeader(i)
-                                        accHeader = atspi.Accessible.makeAccessible(header)
+                                        accHeader = \
+                                            parent_table.getColumnHeader(i)
                                         utterances.append(accHeader.name)
 
                             utterances.extend(self._getSpeechForTableCell(cell,
@@ -1505,7 +1554,8 @@ class SpeechGenerator:
         """
 
         utterances = []
-        if obj.state.count(atspi.Accessibility.STATE_CHECKED):
+        state = obj.getState()
+        if state.contains(pyatspi.STATE_CHECKED):
             # Translators: the state of a toggle button.
             #
             checkedState = _("pressed")
@@ -1623,9 +1673,9 @@ class SpeechGenerator:
 
         Returns a list of utterances to be spoken.
         """
-
-        if self.speechGenerators.has_key(obj.role):
-            generator = self.speechGenerators[obj.role]
+        role = obj.getRole()
+        if self.speechGenerators.has_key(role):
+            generator = self.speechGenerators[role]
         else:
             generator = self._getDefaultSpeech
 
@@ -1649,13 +1699,13 @@ class SpeechGenerator:
         if not obj:
             return utterances
 
-        if obj is stopAncestor:
+        if obj == stopAncestor:
             return utterances
 
         parent = obj.parent
         if parent \
-            and (obj.role == rolenames.ROLE_TABLE_CELL) \
-            and (parent.role == rolenames.ROLE_TABLE_CELL):
+            and (obj.getRole() == pyatspi.ROLE_TABLE_CELL) \
+            and (parent.getRole() == pyatspi.ROLE_TABLE_CELL):
             parent = parent.parent
 
         while parent and (parent.parent != parent):
@@ -1663,17 +1713,17 @@ class SpeechGenerator:
                 break
             if not self._script.isLayoutOnly(parent):
                 text = self._script.getDisplayedLabel(parent)
-                if not text and parent.text:
+                if not text and 'Text' in pyatspi.listInterfaces(parent):
                     text = self._script.getDisplayedText(parent)
                 if text and len(text.strip()):
                     # Push announcement of cell to the end
                     #
-                    if not parent.role in [rolenames.ROLE_TABLE_CELL,
-                                           rolenames.ROLE_FILLER]:
+                    if parent.getRole() not in [pyatspi.ROLE_TABLE_CELL,
+                                                pyatspi.ROLE_FILLER]:
                         utterances.append(\
                             rolenames.getSpeechForRoleName(parent))
                     utterances.append(text)
-                    if parent.role == rolenames.ROLE_TABLE_CELL:
+                    if parent.getRole() == pyatspi.ROLE_TABLE_CELL:
                         utterances.append(\
                             rolenames.getSpeechForRoleName(parent))
             parent = parent.parent
