@@ -24,9 +24,9 @@ machine to speak.  Each speech server provides a set of known
 voices (identified by name) which can be combined with various
 attributes to create aural style sheets."""
 
-__id__        = "$Id: speechserver.py 2548 2007-07-21 21:46:43Z wwalker $"
-__version__   = "$Revision: 2548 $"
-__date__      = "$Date: 2007-07-21 17:46:43 -0400 (Sat, 21 Jul 2007) $"
+__id__        = "$Id: speechserver.py 3018 2007-10-11 17:44:04Z wwalker $"
+__version__   = "$Revision: 3018 $"
+__date__      = "$Date: 2007-10-11 13:44:04 -0400 (Thu, 11 Oct 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -210,8 +210,9 @@ class SpeechServer(object):
             #
             event_string += " " + _("off")
 
-        debug.println(debug.LEVEL_INFO, "SPEECH OUTPUT: '" + event_string +"'")
-        log.info("speakKeyEvent utterance='%s'" % event_string)
+        logLine = "SPEECH OUTPUT: '" + event_string +"'"
+        debug.println(debug.LEVEL_INFO, logLine)
+        log.info(logLine)
 
         self.speak(event_string, acss=voice)
 
@@ -264,9 +265,9 @@ class SpeechServer(object):
                              COMPLETED.
         """
         for [context, acss] in utteranceIterator:
-            debug.println(debug.LEVEL_INFO,
-                          "SPEECH OUTPUT: '" + context.utterance + "'")
-            log.info("sayAll utterance='%s'" % context.utterance)
+            logLine = "SPEECH OUTPUT: '" + context.utterance + "'"
+            debug.println(debug.LEVEL_INFO, logLine)
+            log.info(logLine)
             self.speak(context.utterance, acss)
 
     def increaseSpeechRate(self, step=5):
